@@ -211,9 +211,10 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, id_of_flow, MainAppBase                    # type: ignore
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
+HELP_ID_FLOW_PREFIX = 'help_flow#'
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )  #: tuple of flow ids never search/show help text for
 
 
@@ -427,7 +428,7 @@ class HelpAppBase(MainAppBase, ABC):
         """
         return f'help_app_state#{state_name}'
 
-    def help_display(self, help_id: str, help_vars: Dict[str, Any], widget: Any,
+    def help_display(self, help_id: str, help_vars: Dict[str, Any], widget: Optional[Any] = None,
                      count: Optional[int] = None, key_suffix: str = '', must_have: bool = False):
         """ display help text to the user in activated help flow mode.
 
@@ -481,6 +482,10 @@ class HelpAppBase(MainAppBase, ABC):
 
         nfi = help_vars['new_flow_id']
         if nfi in IGNORED_HELP_FLOWS:
+            if not changed:     # check help target widget is still visible and if not then show initial help text
+                wid = self.widget_by_flow_id(self.help_id_flow())
+                if wid is None or not getattr(wid, 'visible', True):
+                    self.help_display('', dict())
             return changed
 
         help_id = self.help_flow_id(nfi)
@@ -504,14 +509,21 @@ class HelpAppBase(MainAppBase, ABC):
         :param flow_id:         flow id to show help text for.
         :return:                help id for the specified flow id and suffix.
         """
-        return f'help_flow#{flow_id}'
+        return f'{HELP_ID_FLOW_PREFIX}{flow_id}'
+
+    def help_id_flow(self) -> str:
+        """ determine flow id of the current help id. """
+        hid = self.ae_help_id
+        if hid.startswith(HELP_ID_FLOW_PREFIX):
+            return hid[len(HELP_ID_FLOW_PREFIX):]
+        return ''
 
     def help_widget(self, attr_name: str, attr_value: str, help_vars: Dict[str, Any]) -> Optional[Any]:
         """ get help target widget via variable name/value and extend :paramref:`~help_widget.help_vars` locals.
 
         :param attr_name:       widget attribute name for to detect widget and declaration locals.
         :param attr_value:      widget attribute value for to detect widget and declaration locals
-        :param help_vars:       help flow environment variables.
+        :param help_vars:       help flow variables, to be extended with event activation stack frame locals.
         :return:                found help target widget or None if not found.
         """
         depth = 3
